@@ -9,6 +9,7 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/segments"
 
 	"github.com/stretchr/testify/assert"
+	mock2 "github.com/stretchr/testify/mock"
 )
 
 const (
@@ -40,7 +41,7 @@ func TestHasProperty(t *testing.T) {
 func TestMigratePropertyValue(t *testing.T) {
 	cases := []struct {
 		Case     string
-		Expected interface{}
+		Expected any
 		Property properties.Property
 		Props    properties.Map
 	}{
@@ -59,7 +60,7 @@ func TestMigratePropertyValue(t *testing.T) {
 func TestMigratePropertyKey(t *testing.T) {
 	cases := []struct {
 		Case        string
-		Expected    interface{}
+		Expected    any
 		OldProperty properties.Property
 		NewProperty properties.Property
 		Props       properties.Map
@@ -326,7 +327,9 @@ func TestSegmentTemplateMigration(t *testing.T) {
 			Type:       tc.Type,
 			Properties: tc.Props,
 		}
-		segment.migrationOne(&mock.MockedEnvironment{})
+		env := &mock.MockedEnvironment{}
+		env.On("Debug", mock2.Anything).Return(nil)
+		segment.migrationOne(env)
 		assert.Equal(t, tc.Expected, segment.Properties[segmentTemplate], tc.Case)
 	}
 }
