@@ -32,7 +32,7 @@ module.exports = {
       type: "category",
       label: "⚙️ Configuration",
       items: [
-        "configuration/overview",
+        "configuration/general",
         "configuration/block",
         "configuration/segment",
         "configuration/sample",
@@ -57,8 +57,10 @@ module.exports = {
         "segments/az",
         "segments/azfunc",
         "segments/battery",
+        "segments/bazel",
         "segments/brewfather",
         "segments/buf",
+        "segments/carbonintensity",
         "segments/cds",
         "segments/cf",
         "segments/cftarget",
@@ -72,20 +74,21 @@ module.exports = {
         "segments/dotnet",
         "segments/elixir",
         "segments/executiontime",
-        "segments/exit",
         "segments/flutter",
         "segments/fossil",
         "segments/gcp",
+        "segments/firebase",
         "segments/git",
         "segments/gitversion",
         "segments/golang",
         "segments/haskell",
+        "segments/helm",
         "segments/ipify",
-        "segments/iterm",
         "segments/java",
         "segments/julia",
         "segments/kotlin",
         "segments/kubectl",
+        "segments/lastfm",
         "segments/lua",
         "segments/mercurial",
         "segments/nbgv",
@@ -93,6 +96,7 @@ module.exports = {
         "segments/node",
         "segments/npm",
         "segments/nx",
+        "segments/ocaml",
         "segments/os",
         "segments/owm",
         "segments/path",
@@ -100,8 +104,11 @@ module.exports = {
         "segments/php",
         "segments/plastic",
         "segments/project",
+        "segments/pulumi",
         "segments/python",
+        "segments/quasar",
         "segments/r",
+        "segments/react",
         "segments/root",
         "segments/ruby",
         "segments/rust",
@@ -110,14 +117,17 @@ module.exports = {
         "segments/shell",
         "segments/sitecore",
         "segments/spotify",
+        "segments/status",
         "segments/strava",
         "segments/svn",
         "segments/swift",
         "segments/sysinfo",
+        "segments/talosctl",
         "segments/terraform",
         "segments/text",
         "segments/time",
         "segments/ui5tooling",
+        "segments/umbraco",
         "segments/unity",
         "segments/upgrade",
         "segments/vala",
